** This file produces results in section VI of the paper "Detecting illegal arms trade"

** USES: weaponsdataShortAEJ.dta, companydata.dta, compcountrydata.dta, eventsRaw.dta, marketdata.dta,
** marketyeardata.dta, UNdocs.dta

* cd c:\eliana_finished_papers\weapons\paper\AEJPol\final\ReplicationFiles
cd "c:/Users/sdellavi/My Documents/Brief/Research/weapons/AEJDataPosting"



               ******************************************************************
               *    Part 1:  event studies a la McKinlay; generate p-values     *  
               ******************************************************************

** TO BE INPUTED MANUALLY: 
** EVENT DATES (lines 61-79) --- dates w/ unexpected == 1 or 2 take from eventsRaw.dta (later only use unexpected=2)
** NUMBER OF COMPANIES (line 46): in this version 193 (=max id)

** PARAMETERS: event window = (-1,+1);  estimation window = 100


clear all
pwd
set mem 200m
capture log close
set more off

save regs/CAR_pvalues, replace empty

use regs/weapondataShortAEJ, clear

drop mv ret3ri
rename retri Rit
label variable Rit  "return on stock, calculated from ri"
rename retli Rmt
label var Rmt "return on local mkt index"
drop if Rit==. | Rmt==.
encode compname, gen(id)
save regs/data_temp, replace


local country Angola Ethiopia Liberia Rwanda Sierraleone Somalia Sudan Yugoslavia


*** Get p-values

	
forvalues i=1(1)193{
	use regs/data_temp, clear
	keep if id==`i'
	local y : label(id) `i'
		
	*Dates for Unexp = 1 or 2
	local Angola_event "d(22dec1988) d(30jun1989) d(28sep1992) d(14jan1998) d(24jul1998) d(14dec1998) d(28sep1999) d(20oct1999) d(07may2001) d(13aug2001) d(22feb2002) d(01apr2002)" 
	local Ethiopia_event  "d(08feb1999) d(12may2000) d(23may2000) d(14jun2000) d(12dec2000)"
	local Liberia_event "d(06jan1986) d(21aug1995) d(29apr1996) d(21sep1998) d(10aug1999) d(05jun2003) d(24jun2003) d(07aug2003)" 
	local Rwanda_event  "d(08feb1993) d(19may1993) d(21oct1993) d(06apr1994) d(04jul1994)"	
	local Sierraleone_event "d(29apr1992) d(26feb1996) d(26may1997) d(10mar1998) d(06jan1999) d(18may1999) d(17may2000)"
	local Somalia_event "d(04apr1988) d(14jul1989) d(01jan1991) d(04oct1993) d(02aug1996) d(28oct2002)"
	local Sudan_event "d(08apr1985) d(18aug1986) d(15nov1988) d(13mar1989) d(30jun1989) d(13dec1999) d(22jul2002) d(01aug2005)"
	local Yugoslavia_event "d(25jun1991) d(06apr1992) d(21nov1995) d(11apr1997) d(22dec1998) d(15jan1999) d(30mar2001) d(12mar2003) d(17mar2004)"									   

		
	egen n_count = count(Rit)
	label variable n_count "number of nonmissing observations"

	sort date
	format date %d
	gen ind=_n
	sum ind
	sca min_n=r(min)
	sca max_n=r(max)
	
	di "************`y'***************"
		
	foreach c of local country{

		di "*******`c'*********"
	
		foreach x of local `c'_event{
			cap noisily{
				di "*******`x'*********"

				gen i=ind if date==`x'
				replace i=0 if i==.
				egen i2=sum(i)
				scalar define event=i2 in 1
				local evno=event
				drop i i2 
				scalar define t2=event-1
				scalar define t4=event+1
				scalar define t1=t2-100
				scalar define t2_1=t2-1
			preserve
				if t2>=min_n&t4<=max_n {
				
					* AR		
					reg Rit Rmt if ind>=t1 & ind<t2
					sca nobsestwin=e(N)
					scalar define sigma=e(rss)/(nobsestwin-2)
					predict ar, resid
		
					* CAR
					gen car=sum(ar) if ind>=t2&ind<=t4
		

					* CAR Variance
					matrix drop _all
					gen ones=1
					mkmat ones Rmt if ind>=t2 & ind<=t4, matrix(Xstar)
					mkmat ones Rmt if ind>=t1 & ind<t2, matrix(X)
					scalar define h=3
					* h is lenght of event window, used for # of rows and # of colums of identity matrix	
					matrix identity = I(h)
					matrix Vhat=(identity + (Xstar*syminv(X'*X)*Xstar'))*sigma

					*  Test Statistic

					mkmat ones if ind<=h, matrix(i)
					gen p=car if ind==t4
					replace p=0 if p==.
					egen p2=sum(p)
					scalar define CARt4=p2 in 1
					drop p p2
					matrix iVhati=i'*Vhat*i
					scalar define iVhati1=iVhati[1,1]

					scalar define test=CARt4/sqrt(iVhati1)
					scalar define abstest=abs(test)
					scalar define df=nobsestwin -2
					di ""
		
					di "TEST t =   " test
					di "Ho: CAR=0"
					di "Ha: CAR<0,  P<t=   " 1-ttail(df, test)
					di "Ha: CAR~=0,  P>|t|=   " 2*ttail(df, abstest)
					di "Ha: CAR>0,  P>t=   " ttail(df, test)
		
					gen CARneg =  1-ttail(df, test)
					label variable CARneg "P-value of Ha: CAR<0"
					gen CARpos =  ttail(df, test)
					label variable CARpos "P-value of Ha: CAR>0"

				
					gen ev_date = `x'
					egen car_t4=max(car)
					gen nobsestwin=nobsestwin
					collapse  CARneg ev_date CARpos car_t4, by (compname listing)
					gen str23 country = "`c'"

					append using regs/CAR_pvalues.dta
	
					save regs/CAR_pvalues, replace
					}
			
				else {
					di ""	
					di " No sufficient data for date `x'  Event window -1, +1"
					di ""
					
					keep if _n==1
					gen ev_date = `x'
					gen car=.
					gen CARneg=.
					gen CARpos=.
					gen car_t4=.
					gen str23 country = "`c'"
					keep listing  compname ev_date CARneg CARpos car_t4 country
					append using regs/CAR_pvalues.dta

					save regs/CAR_pvalues, replace
					}
				}
			restore					
			}
		}
	}



*** Transform p-values into codes 0, 1,-1

use regs/CAR_pvalues, clear

rename CARneg CARneg_p
rename CARpos CARpos_p

gen CARneg = -1 if CARneg_p<=0.1
replace CARneg = 0 if CARneg_p>0.1 & CARneg_p~=.
label variable CARneg "-1=signif 10%; 0=insignif"  

gen CARpos = 1 if CARpos_p<=0.1
replace CARpos= 0 if CARpos_p>0.1 & CARpos_p~=.
label variable CARpos "1=signif 10%; 0=insignif"  

egen CARsignif = rsum (CARpos CARneg) if CARpos_p~=.
label variable CARsignif "1=CAR>0 at 10%, -1=CAR<0 at 10%, 0=insignif"

drop CARpos CARneg CARneg_p CARpos_p
rename CARsignif T
rename car_t4 C
recode T (.=9999)
recode C (.=9999)

drop listing 
reshape wide T C, i(ev_date country) j(compname) string
keep ev_date country T*
mvdecode T*, mv(9999=.)

save regs/car_final_pvalues, replace
clear

erase regs/data_temp.dta



	       ****************************************************
               *    Part 2:  define legal & illegal reactions     *  
               ****************************************************
               
               
clear all
tempfile temp 
save regs/effects, replace empty

use regs/eventsRaw, clear
keep country unembargo increase unexpected date

rename date date_event
gen date=date_event
format date %d
rename date dateorig
gen date=dateorig
sort date
* Correction for weekend
gen weekday=dow(date)
replace date=date+2 if weekday==6
replace date=date+1 if weekday==0
drop weekday*
gen ev_date=date
format ev_date %d
drop date date_event dateorig

replace country = "Sierraleone" if country=="Sierra Leone"

* Keep only events highly unexpected
keep if unexpected==2

replace increase = "-1" if increase=="-"
replace increase = "+1" if increase=="+"
destring increase, replace ignore(?)


sort country ev_date
save regs/temp, replace


use regs/car_final_pvalues, clear
sort country ev_date
merge country ev_date using regs/temp
tab _m
keep if _m==3
drop _m

save regs/embargo_pvalues, replace


local country Angola Ethiopia Liberia Rwanda Sierraleone Somalia Sudan Yugoslavia

**macro to insert all company names in the local company
sort T*
local company: sortedby

foreach c of local country {
	use regs/embargo_pvalues, clear
	keep if country=="`c'"

	* Generate signs of reactions consistent w/ legal & illegal behavior
	* legal is defined outside & inside embargo, illegal only inside

	gen byte inside = (unembargo==1 & unexpected==2)|(unembargo==2 & unexpected==2)
	label var inside "Strict; =1 inside embargo; =0 outside"

	gen outeffect = increase if inside==0
	gen illegaleffect = increase if inside==1
	label var outeffect "sign of consistent reaction outside embargo"
	label var illegaleffect "sign of ILLEGAL reaction during embargo"


	* Calculate number of chains theoretically possible for each country
	* Let n=# obs inside and m=# obs outside
	* Chain inside-inside is n^(r)/r!
	* Chain outside-inside is m*n

	sort ev_date
	egen nobs=sum(1), by(inside)
	egen nobs_i=sum(inside==1)
	egen nobs_o=sum(inside==0)
	gen ncomb_i=comb(nobs_i,2) if nobs_i>1
	replace ncomb_i=0 if nobs_i==0 | nobs_i==1
	gen ncomb_io=nobs_i*nobs_o
	gen ncombctry=ncomb_i+ncomb_io
	drop ncomb_i ncomb_io 
	sort ev_date

	* Combine actual company reaction w/ predicted legal or illegal reaction
	* "+" will stand for consistent reaction, "-" for inconsistent reaction , i.e.
	* if i_`p' is positive, reaction is consistent w/ illegal behavior

	sort T*
	local company: sortedby

	foreach p of local company {
		*rename T`p' `p'
		gen o_`p' = `p'*outeffect
		gen i_`p' = `p'*illegaleffect
		
		* Count how many times a company had a reaction consistent w/ legal or illegal behaviour
		* Count number of significant chains

		*No. of chains in which company had nonmissing data: ncomb_`p'
		egen nro_`p'=sum(o_`p'!=.)
		egen nri_`p'=sum(i_`p'!=.)
		gen ncomb_i`p'=comb(nri_`p',2) if nri_`p'>1
		replace ncomb_i`p'=0 if nri_`p'==0 | nri_`p'==1
		gen ncomb_io`p'=nro_`p'*nri_`p'
		gen ncomb_`p'=ncomb_io`p'+ ncomb_i`p'
		drop ncomb_io`p'  ncomb_i`p'
	
		*No. of chains in which company had illegal reaction at 10% level: nChain10_`p'
		egen nso10_`p'=sum(o_`p'>0 & o_`p'!=.)
		egen nsi10_`p'=sum(i_`p'>0 & i_`p'!=.)
		gen nscomb_i`p'=comb(nsi10_`p',2) if nsi10_`p'>1
		replace nscomb_i`p'=0 if nsi10_`p'==0 | nsi10_`p'==1
		gen nscomb_io`p'=nso10_`p'*nsi10_`p'
		gen nChain10_`p'=nscomb_io`p'+ nscomb_i`p'
		drop nscomb_io`p'  nscomb_i`p'

	
		egen count_out10_`p' = sum(o_`p'>0 & o_`p'!=.)
		gen out10_`p' = count_out10_`p'/nro_`p'
		drop count_*

		egen count_ill10_`p' = sum(i_`p'>0 & i_`p'!=.)
		gen ill10_`p' = count_ill10_`p'/nri_`p'
		
	
		gen illplus10_`p' = (count_ill10_`p'>1 & count_ill10_`p'!=.)
		
		drop count_*


		egen count_leg10_`p' = sum(i_`p'<0 & i_`p'!=.)
		gen leg10_`p' = count_leg10_`p'/nri_`p'
		
		gen legplus10_`p' = (count_leg10_`p'>1 & count_leg10_`p'!=.)
		
		drop count_*

		}


	** Keep only relevant vbls

	gen counter=sum(1)
	keep if counter==1


	append using regs/effects.dta
	save regs/effects, replace

	}


*** Easy results to read in excel

use regs/effects, clear 
keep country out* ill* leg* nobs_i nobs_o ncombctry nro* nri* nso* nsi* ncomb_* nChain*
sort country

*Order all types of reactions company by company
	
foreach p of local company {
	order  out10_`p' ill10_`p' leg10_`p' 
	}
order country nobs* ncomb* nChain*


*** Reshape data to construct "chain" indicator

reshape long nChain10_ nro_ nri_ ncomb_ nso10_ nsi10_ out10_ ill10_ leg10_ illplus10_ legplus10_ , i(country) j(company) string
gen chain10_ill = (out10_>0 & ill10_>0) if (out10_!=. & ill10_!=.)
gen Chain10_ill = chain10_ill
replace Chain10_ill = 0 if (Chain10_ill==. & illplus10_!=.)
replace Chain10_ill = 1 if illplus10_==1
gen chain10_leg = (out10_>0 & leg10_>0) if (out10_!=. & leg10_!=.)
gen Chain10_leg = chain10_leg
replace Chain10_leg = 0 if (Chain10_leg==. & legplus10_!=.)
replace Chain10_leg = 1 if legplus10_==1

label var nChain10 "# illegal Chains: react outside emb & illegally inside emb OR >2 times ill during emb sign.10%"
label var chain10_ill "1= react outside emb & illegally inside emb sign.10%"
label var Chain10_ill "1= react outside emb & illegally inside emb OR >2 times ill during emb sign.10%"
label var chain10_leg "1= react outside emb & legally inside emb sign.10%"
label var Chain10_leg "1= react outside emb & legally inside emb OR >2 times leg during emb sign.10%"
label var out10_ "share of consistent reactions outside embargo sign.10%"
label var ill10_ "share of illegal reactions during embargo sign.10%"
label var leg10_ "share of legal reactions during embargo sign.10%"
label var illplus10_ "2 or more illegal reactions during embargo sign.10%"
label var legplus10_ "2 or more legal reactions during embargo sign.10%"

drop chain*
	
order  country  company nobs_i nobs_o ncombctry  nro_ nri_  ncomb_ nChain10_
rename ncombctry ncomb_ctry
rename nobs_i nri_ctry
rename nobs_o nro_ctry
rename nro_ nro_comp
rename nri_  nri_comp
rename ncomb_ ncomb_comp
rename nso10_ nso10_comp
rename nsi10_ nsi10_comp
rename nChain10_ nChain10
gen weight=ncomb_comp/ncomb_ctry
	
label var ncomb_ctry "# of possible chains for each conflict"
label var ncomb_comp "# of possible chains with non mssing data for each company-conflict"
label var weight "ncomb_comp/ncomb_ctry"
label var nri_ctry "# events inside embargo for each conflict"
label var nro_ctry "# events outside embargo for each conflict"
label var nri_comp "# non missing obs inside embargo for each company-conflict"
label var nro_comp "# non missing obs outside embargo for each company-conflict"
label var nsi10_comp "# illeg reactions signif 10% inside embargo for each company-conflict"
label var nso10_comp "# reactions signif 10% outside embargo for each company-conflict"


gen company1=substr(company,2,.)
drop company
rename company1 company
order country company
save regs/effects_evow1, replace

erase regs/effects.dta



	       ***********************************************************
               *    Part 3:  prepare data for regressions in Table 6     *  
               ***********************************************************
               

clear all
tempfile temp 
save regs/DataForTab6, replace empty


use regs/embargo_pvalues, clear


local country Angola Ethiopia Liberia Rwanda Sierraleone Somalia Sudan Yugoslavia

sort T*
local company: sortedby


foreach c of local country {

	use regs/embargo_pvalues, clear
	keep if country=="`c'"

	* Generate signs of reactions consistent w/ legal & illegal behavior
	* legal is defined outside & inside embargo, illegal only inside

	gen byte inside = (unembargo==1 & unexpected==2)|(unembargo==2 & unexpected==2)
	label var inside "Strict; =1 inside embargo; =0 outside"

	gen outeffect = increase if inside==0
	gen illegaleffect = increase if inside==1
	label var outeffect "sign of consistent reaction outside embargo"
	label var illegaleffect "sign of ILLEGAL reaction during embargo"


	* Combine actual company reaction w/ predicted legal or illegal reaction
	* "+" will stand for consistent reaction, "-" for inconsistent reaction , i.e.
	* if i_`p' is positive, reaction is consistent w/ illegal behavior

	foreach p of local company {
		gen o_`p' = `p'*outeffect
		gen i_`p' = `p'*illegaleffect
				
		* For each event window, gen DUMMY =1 if company had a reaction
		* consistent w/ legal or illegal behaviour

		sort ev_date
		bys inside: gen out10_`p' = (o_`p'>0) if o_`p'!=.
		bys inside: gen ill10_`p' = (i_`p'>0) if i_`p'!=.
		bys inside: gen leg10_`p' = (i_`p'<0) if i_`p'!=.
		egen outside10_`p' = max(out10_`p')
		sort ev_date
		}

	keep if inside==1
	drop inside

	keep country ev_date outside10_* ill10_* leg10_* 

	append using regs/DataForTab6.dta
	save regs/DataForTab6, replace

	}



** Reshape & merge w/ company info

reshape long outside10_ ill10_ leg10_ , i(country ev_date) j(company) string

label var ill10_ "1=illegal reaction at 10% level"
label var leg10_ "1=legal reaction at 10% level"
label var outside10_ "1=at least one consistent reaction outside at 10% level"

gen compname=substr(company,2,.)
drop company
gen year = year(ev_date)
order country compname year
sort compname country

replace country="Sierra Leone" if country=="Sierraleone"

save regs/DataForTab6, replace

use regs/companydata, clear
sort compname
merge compname using regs/DataForTab6
tab _merge
* 27 obs w/ _m=1
keep if _m==3
drop _merge

sort compname country
merge compname country using regs/compcountrydata
tab _merge
* 50 obs w/ _m=2
drop if _m==2
drop _m

sort market
merge market using regs/marketdata
tab _merge
* 18 obs with _m=1 (from Taiwan)
drop if _m==1
drop _m

sort market year
merge market year using regs/marketyeardata
tab _merge
* 448 obs with _m=2 (these are missing values with no compname associated)
drop if _m==2
drop _m
label var cpi "Corruption Perception Index, time varying"
label var pressfr "Press Freedom Index, time varying"

compress
sort country ev_date compname

encode compname, gen(companycode)
drop compname

save regs/DataForTab6, replace



	       **********************************************
               *    Part 4:  run regressions in Table 6     *  
               *             OLS, clustering by date        *
               **********************************************
               
 
 use regs/DataForTab6, clear
 
 
 keep if dwscope==1|dsipri==1
 
 *drop 3 companies less than 200 obs for returns (variable retri in weaponsdataShortAEJ.dta)
 drop if compname=="ittinds"
 drop if compname=="mtuaeh"
 drop if compname=="rollsroyce"
 *"meopta", "qinetiq" and "specialdev" already dropped out
 
 sort country
 merge country using regs/UNdocs
 tab _m
 drop _m
 
 
 *** Panel A: ILLEGAL - Incidence by country (UN documents) ***
 
 regr ill10_ mgpedocs_yr , cluster(ev_date)
 outreg using output/TablesAEJOct10/tab6_a, nolabel title(Prob of illegal reactions - dummies) ctitle(ill10) se 3aster bdec(4) rdec(4) replace
 
 regr ill10_ seldocs_yr , cluster(ev_date)
 outreg using output/TablesAEJOct10/tab6_a, nolabel ctitle(ill10) se 3aster bdec(4) rdec(4) append
 
 regr ill10_ hitshgd90emb , cluster(ev_date)
 outreg using output/TablesAEJOct10/tab6_a, nolabel ctitle(ill10) se 3aster bdec(4) rdec(4) append
 
 regr ill10_ hitshgd90arms , cluster(ev_date)
 outreg using output/TablesAEJOct10/tab6_a, nolabel ctitle(ill10) se 3aster bdec(4) rdec(4) append
 
 regr ill10_ hitshgd90ctry , cluster(ev_date)
 outreg using output/TablesAEJOct10/tab6_a, nolabel ctitle(ill10) se 3aster bdec(4) rdec(4) append
 
 
 *** Panel B: LEGAL - Incidence by country (UN documents) ***
 
 regr leg10_ mgpedocs_yr , cluster(ev_date)
 outreg using output/TablesAEJOct10/tab6_b, nolabel title(Prob of legal reactions - dummies) ctitle(leg10) se 3aster bdec(4) rdec(4) replace
 
 regr leg10_ seldocs_yr , cluster(ev_date)
 outreg using output/TablesAEJOct10/tab6_b, nolabel ctitle(leg10) se 3aster bdec(4) rdec(4) append
 
 regr leg10_ hitshgd90emb , cluster(ev_date)
 outreg using output/TablesAEJOct10/tab6_b, nolabel ctitle(leg10) se 3aster bdec(4) rdec(4) append
 
 regr leg10_ hitshgd90arms , cluster(ev_date)
 outreg using output/TablesAEJOct10/tab6_b, nolabel ctitle(leg10) se 3aster bdec(4) rdec(4) append
 
 regr leg10_ hitshgd90ctry , cluster(ev_date)
 outreg using output/TablesAEJOct10/tab6_b, nolabel ctitle(leg10) se 3aster bdec(4) rdec(4) append
 
 

	       **********************************************
               *    Part 5:  replicate Appendix Table A8    *  
               **********************************************
 

use regs/effects_evow1, clear
rename company compname
sort compname
merge compname using regs/companydata
tab _m
* 27 obs w/ _m=2  (missing info on country)
keep if _merge==3
drop _merge
keep if dwscope==1|dsipri==1

*drop 3 companies less than 200 obs for returns (variable retri in weaponsdataShortAEJ.dta)
drop if compname=="ittinds"
drop if compname=="mtuaeh"
drop if compname=="rollsroyce"
*"meopta", "qinetiq" and "specialdev" already dropped out

sort market
merge market using regs/marketdata
tab _merge
drop _m

sort compname country
encode compname, gen(companyid)
drop compname
save regs/DataForTabA8.dta, replace


cap log close
log using output/TablesAEJOct10/TableA8.log, replace



******* Appendix Table A8:  Chains of illegal reactions


dis ""
dis "****** Chain10_ill ********"
dis ""


dis ""
dis "**Full sample"
dis ""

preserve
collapse(sum) nChain10 ncomb_comp
gen ratio= nChain10/ncomb_comp
l
restore

dis ""
dis "**Companies w/ chains in more than one country"
dis ""

preserve
egen tempvar = sum(Chain10_ill), by(companyid)
collapse (mean) tempvar, by(companyid)
tab tempvar 
restore


dis ""
dis "**By conflict"
preserve
collapse(sum) nChain10 ncomb_comp, by(country)
gen ratio= nChain10/ncomb_comp
l
restore


dis ""
dis "**By CPI"
preserve
collapse(sum) nChain10 ncomb_comp, by(d2cpi)
gen ratio= nChain10/ncomb_comp
l
restore

dis ""
dis "**By Arms Transparency"
preserve
collapse(sum) nChain10 ncomb_comp, by(d2transp)
gen ratio= nChain10/ncomb_comp
l
restore

dis ""
dis "**By OECD"
preserve
collapse(sum) nChain10 ncomb_comp, by(samplenowest)
gen ratio= nChain10/ncomb_comp
l
restore

dis ""
dis "**By BPI"
preserve
collapse(sum) nChain10 ncomb_comp, by(d2bpi06)
gen ratio= nChain10/ncomb_comp
l
restore

dis ""
dis "**By press freedom"
preserve
collapse(sum) nChain10 ncomb_comp, by(d2pressfr)
gen ratio= nChain10/ncomb_comp
l
restore

dis ""
dis "**By Self-dealing"
preserve
collapse(sum) nChain10 ncomb_comp, by(d2nodeal)
gen ratio= nChain10/ncomb_comp
l
restore


log close
clear              

              
erase regs/CAR_pvalues.dta
erase regs/car_final_pvalues.dta
erase regs/embargo_pvalues.dta
erase regs/effects_evow1.dta


               
